DSFirebaseDatabaseProvider class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

beginTransaction() Future<DSTransaction>
Begins a transaction
createDocument(String collection, Map<String, dynamic> data) Future<String>
Creates a document in the specified collection
deleteDocument(String collection, String id) Future<void>
Deletes a document from the specified collection
dispose() Future<void>
Releases any resources used by the provider
getNativeClient() → dynamic
Gets the native database client for raw operations
initialize(Map<String, dynamic> config) Future<void>
Initialize the database provider with configuration settings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryDocuments(String collection, {required Map<String, dynamic> where, int? limit, String? orderBy, bool descending = false}) Future<List<Map<String, dynamic>>>
Queries documents from the specified collection based on criteria
readDocument(String collection, String id) Future<Map<String, dynamic>?>
Reads a document from the specified collection by ID
toString() String
A string representation of this object.
inherited
updateDocument(String collection, String id, Map<String, dynamic> data) Future<void>
Updates a document in the specified collection

Operators

operator ==(Object other) bool
The equality operator.
inherited